@@ -1,6 +1,6 @@
-#!/usr/bin/env python
+#!/usr/bin/python2
 
-import os, sys, commands
+import os, sys
 import gtk
 import gtk.glade
 import pygtk
@@ -217,5 +217,7 @@ class DropZone():
         del self.dropZones[self.service['name']]
 
 gtk.gdk.threads_init()
+gtk.gdk.threads_enter()
 MainClass()
 gtk.main()
+gtk.gdk.threads_leave()
